/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.controller.api;

import static fr.unistra.sil.erp.back.WebMvcConfig.MAPPING_GETSTOCKS;
import fr.unistra.sil.erp.back.DatabaseSystem;
import fr.unistra.sil.erp.back.controller.IRetrieveStocks;
import fr.unistra.sil.erp.back.db.DatabaseConnectionException;
import fr.unistra.sil.erp.back.db.DatabaseInterface;
import fr.unistra.sil.erp.back.model.Stock;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * Retrieves stocks in JSON format.
 * @author BEAUVAIS ANTOINE
 */
@RestController
public class ApiRetrieveStocks implements IRetrieveStocks {

    /**
     * Sends the stocks as JSON format back to the client.
     * @param request the HTTP request.
     * @param response the HTTP response.
     * @return the response. 
     * @throws ApiServerErrorException if the request could not be served.
     */
    @GetMapping(MAPPING_GETSTOCKS)
    @Override
    public ResponseEntity<Object> retrieveStocks(HttpServletRequest request,
            HttpServletResponse response) throws ApiServerErrorException {
        DatabaseInterface db;
        try {
            db = DatabaseSystem.getInstance();
        } catch (DatabaseConnectionException ex) {
            Logger.getLogger(ApiRetrieveCategoriesController.class.getName())
                    .log(Level.SEVERE, "Failed to connect to database.", ex);
            throw new ApiServerErrorException("Database failure.");
        }
        
        List<Stock> res = db.getStocks();
        if(res == null)
            throw new ApiServerErrorException("Database failure.");
        
        return new ResponseEntity<>(res, HttpStatus.OK);
    }
    
}
